.. labscript suite documentation master file

.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   changes
   contributing
   archive
   Home Page <http://labscriptsuite.org>
   Source Code <https://github.com/labscript-suite/labscript-suite>

.. mdinclude:: main.md
